Simple

Struct Simple 

pub struct Simple(/* private fields */);
Format a Uuid as a simple string, like 67e5504410b1426f9247bb680e5fe0c8.

Implementations

Source

impl Simple

pub const LENGTH: usize = 32

The length of a simple Uuid string.

pub const fn from_uuid(uuid: Uuid) -> Simple

Creates a Simple from a Uuid.

pub fn encode_lower<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str

Writes the Uuid as a lower-case simple string to buffer, and returns the subslice of the buffer that contains the encoded UUID.

This is slightly more efficient than using the formatting infrastructure as it avoids virtual calls, and may avoid double buffering.

Panics

Panics if the buffer is not large enough: it must have length at least LENGTH. Uuid::encode_buffer can be used to get a sufficiently-large temporary buffer.

Examples
use uuid::Uuid;

fn main() -> Result<(), uuid::Error> {
    let uuid = Uuid::parse_str("936DA01f9abd4d9d80c702af85c822a8")?;

    // the encoded portion is returned
    assert_eq!(
        uuid.simple().encode_lower(&mut Uuid::encode_buffer()),
        "936da01f9abd4d9d80c702af85c822a8"
    );

    // the buffer is mutated directly, and trailing contents remains
    let mut buf = [b'!'; 36];
    assert_eq!(
        uuid.simple().encode_lower(&mut buf),
        "936da01f9abd4d9d80c702af85c822a8"
    );
    assert_eq!(
        &buf as &[_],
        b"936da01f9abd4d9d80c702af85c822a8!!!!" as &[_]
    );

    Ok(())
}

*/

pub fn encode_upper<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str

Writes the Uuid as an upper-case simple string to buffer, and returns the subslice of the buffer that contains the encoded UUID.

Panics

Panics if the buffer is not large enough: it must have length at least LENGTH. Uuid::encode_buffer can be used to get a sufficiently-large temporary buffer.

Examples
use uuid::Uuid;

fn main() -> Result<(), uuid::Error> {
    let uuid = Uuid::parse_str("936da01f9abd4d9d80c702af85c822a8")?;

    // the encoded portion is returned
    assert_eq!(
        uuid.simple().encode_upper(&mut Uuid::encode_buffer()),
        "936DA01F9ABD4D9D80C702AF85C822A8"
    );

    // the buffer is mutated directly, and trailing contents remains
    let mut buf = [b'!'; 36];
    assert_eq!(
        uuid.simple().encode_upper(&mut buf),
        "936DA01F9ABD4D9D80C702AF85C822A8"
    );
    assert_eq!(
        &buf as &[_],
        b"936DA01F9ABD4D9D80C702AF85C822A8!!!!" as &[_]
    );

    Ok(())
}

*/

pub const fn as_uuid(&self) -> &Uuid

Get a reference to the underlying Uuid.

Examples
use uuid::Uuid;

let simple = Uuid::nil().simple();
assert_eq!(*simple.as_uuid(), Uuid::nil());
pub const fn into_uuid(self) -> Uuid

Consumes the Simple, returning the underlying Uuid.

Examples
use uuid::Uuid;

let simple = Uuid::nil().simple();
assert_eq!(simple.into_uuid(), Uuid::nil());